Crate encrust_core

Crate encrust_core 

encrust-core

Core implementation crate for encrust.

Most users should depend on encrust instead. This crate exposes the storage types and traits used by the public facade and the encrust-macros crate.

License: MIT

Structs

DecrustGuard
Guard used to access decrusted data.
Encrusted
Container for encrusted data.
Hashbyteshashstrings
Represents the hash of a byte slice.
Hashstringhashstrings
Represents the hash of a string.

Enums

Sensitivityhashstrings
Used to specify whether a Hashstring should ignore case when comparing strings.

Traits

Encrust
Trait for types that can be stored in Encrusted.
InPlaceEncrust
A simpler alternative to Encrust for types where Storage and Ref are Self.